@@ -57,23 +57,29 @@ Counter <- function(data, num_sets, start_col, name_of_sets, nintersections, mba
 }
 
 ## Generate main bar plot
-Make_main_bar <- function(Main_bar_data, Q, show_num, ratios, customQ, number_angles){
+Make_main_bar <- function(Main_bar_data, Q, show_num, ratios, customQ, number_angles, ebar){
   if(is.null(Q) == F){
     inter_data <- Q
     if(nrow(inter_data) != 0){
       inter_data <- inter_data[order(inter_data$x), ]
     }
-    else{
-      inter_data <- NULL
+    else{inter_data <- NULL}
+  }
+  else{inter_data <- NULL}
+  
+  if(is.null(ebar) == F){
+    elem_data <- ebar
+    if(nrow(elem_data) != 0){
+      elem_data <- elem_data[order(elem_data$x), ]
     }
+    else{elem_data <- NULL}
   }
-  else{
-    inter_data <- NULL
-  }
+  else{elem_data <- NULL}
+  
   #ten_perc creates appropriate space above highest bar so number doesnt get cut off
   ten_perc <- ((max(Main_bar_data$freq)) * 0.1)
   Main_bar_plot <- (ggplot(data = Main_bar_data, aes_string(x = "x", y = "freq")) 
-                    + geom_bar(stat = "identity", colour = Main_bar_data$color, width = 0.6, 
+                    + geom_bar(stat = "identity", width = 0.6, 
                                fill = Main_bar_data$color)
                     + scale_x_continuous(limits = c(0,(nrow(Main_bar_data)+1 )), expand = c(0,0),
                                          breaks = NULL)
@@ -91,6 +97,13 @@ Make_main_bar <- function(Main_bar_data, Q, show_num, ratios, customQ, number_an
   pInterDat <- NULL
   bCustomDat <- NULL
   pCustomDat <- NULL
+  bElemDat <- NULL
+  pElemDat <- NULL
+  if(is.null(elem_data) == F){
+    bElemDat <- elem_data[which(elem_data$act == T), ]
+    bElemDat <- bElemDat[order(bElemDat$x), ]
+    pElemDat <- elem_data[which(elem_data$act == F), ]
+  }
   if(is.null(inter_data) == F){
     bInterDat <- inter_data[which(inter_data$act == T), ]
     bInterDat <- bInterDat[order(bInterDat$x), ]
@@ -101,16 +114,22 @@ Make_main_bar <- function(Main_bar_data, Q, show_num, ratios, customQ, number_an
     bCustomDat <- customQ[which(customQ$act == T), ]
     bCustomDat <- bCustomDat[order(bCustomDat$x), ]
   }
+  
   if(length(bInterDat) != 0){
     Main_bar_plot <- Main_bar_plot + geom_bar(data = bInterDat,
                                               aes_string(x="x", y = "freq"), colour = bInterDat$color,
-                                              fill = bInterDat$color, colour ="black",
+                                              fill = bInterDat$color,
+                                              stat = "identity", position = "identity", width = 0.6)
+  }
+  if(length(bElemDat) != 0){
+    Main_bar_plot <- Main_bar_plot + geom_bar(data = bElemDat,
+                                              aes_string(x="x", y = "freq"), colour = bElemDat$color,
+                                              fill = bElemDat$color,
                                               stat = "identity", position = "identity", width = 0.6)
   }
   if(length(bCustomDat) != 0){
-    
     Main_bar_plot <- (Main_bar_plot + geom_bar(data = bCustomDat, aes_string(x="x", y = "freq2"),
-                                               fill = bCustomDat$color2, colour = "black",
+                                               fill = bCustomDat$color2,
                                                stat = "identity", position ="identity", width = 0.6))
   }
   if(length(pCustomDat) != 0){
@@ -122,6 +141,11 @@ Make_main_bar <- function(Main_bar_data, Q, show_num, ratios, customQ, number_an
                                                  position = position_jitter(width = 0.2, height = 0.2),
                                                  colour = pInterDat$color, size = 2, shape = 17))
   }
+  if(length(pElemDat) != 0){
+    Main_bar_plot <- (Main_bar_plot + geom_point(data = pElemDat, aes_string(x="x", y = "freq"),
+                                                 position = position_jitter(width = 0.2, height = 0.2),
+                                                 colour = pElemDat$color, size = 2, shape = 17))
+  }
   
   Main_bar_plot <- (Main_bar_plot 
                     + geom_vline(xintercept = 0, color = "gray0")
@@ -129,5 +153,4 @@ Make_main_bar <- function(Main_bar_data, Q, show_num, ratios, customQ, number_an
   
   Main_bar_plot <- ggplotGrob(Main_bar_plot)
   return(Main_bar_plot)
-}
-
+}
\ No newline at end of file
